Error

Enum Error 

pub enum Error {
Show 41 variants SystemInit(String), ActorCreation { actor: String, reason: String, }, MissingResource { name: String, reason: String, }, Network(String), NetworkState(String), RequestProcessing(String), InvalidSignature(String), SigningFailed(String), RequestNotFound(String), InvalidRequestState(String), InvalidApprovalState(String), ApprovalNotFound(String), ApprovalUpdateFailed(String), SubjectNotFound(String), SubjectNotActive(String), GovernanceNotFound(String), GovernanceHasTrackers { governance_id: String, trackers: Vec<String>, }, InvalidSubjectId(String), Unauthorized(String), Forbidden(String), SafeMode(String), AuthOperation(String), WitnessesNotFound(String), QueryFailed(String), NoEventsFound(String), EventNotFound { subject: String, sn: u64, }, InvalidQueryParams(String), DatabaseError(String), ValidationFailed(String), InvalidEventRequest(String), SchemaValidation(String), ActorCommunication { actor: String, }, UnexpectedResponse { actor: String, expected: String, received: String, }, ActorError(String), TransferFailed(String), NoPendingTransfers, DistributionFailed(String), UpdateFailed(String, String), Internal(String), Timeout(String), NotImplemented(String),
}
Core API errors that may be returned to users.

Variants



SystemInit(String)

System initialization failed.



ActorCreation

Failed to create a required actor.

Fields

actor: String
reason: String


MissingResource

Required helper or resource not found.

Fields

name: String
reason: String


Network(String)

Network operation failed.



NetworkState(String)

Unable to retrieve network state.



RequestProcessing(String)

Request could not be processed.



InvalidSignature(String)

Request signature is invalid or verification failed.



SigningFailed(String)

Node was unable to sign the request.



RequestNotFound(String)

Request not found in tracking system.



InvalidRequestState(String)

Request is in an invalid state for this operation.



InvalidApprovalState(String)

Invalid approval state transition.



ApprovalNotFound(String)

Approval not found for subject.



ApprovalUpdateFailed(String)

Failed to update approval state.



SubjectNotFound(String)

Subject not found.



SubjectNotActive(String)

Subject is not active.



GovernanceNotFound(String)

Governance not found.



GovernanceHasTrackers

Governance still has trackers associated and cannot be deleted.

Fields

governance_id: String
trackers: Vec<String>


InvalidSubjectId(String)

Invalid subject identifier.



Unauthorized(String)

Authorization failed.



Forbidden(String)

Insufficient permissions for operation.



SafeMode(String)

Node is running in safe mode and mutating operations are disabled.



AuthOperation(String)

Authentication subject operation failed.



WitnessesNotFound(String)

Witnesses not found for subject.



QueryFailed(String)

Query execution failed.



NoEventsFound(String)

No events found matching criteria.



EventNotFound

Event not found at specified sequence number.

Fields

subject: String
sn: u64


InvalidQueryParams(String)

Invalid query parameters.



DatabaseError(String)

Database query error.



ValidationFailed(String)

Request validation failed.



InvalidEventRequest(String)

Invalid event request format.



SchemaValidation(String)

Schema validation failed.



ActorCommunication

Actor communication failed.

Fields

actor: String


UnexpectedResponse

Received unexpected response from actor.

Fields

actor: String
expected: String
received: String


ActorError(String)

Actor returned an error.



TransferFailed(String)

Subject transfer operation failed.



NoPendingTransfers

No pending transfers found.



DistributionFailed(String)

Manual distribution failed.



UpdateFailed(String, String)

Update operation failed.



Internal(String)

Internal server error (catch-all for unexpected errors).



Timeout(String)

Operation timed out.



NotImplemented(String)

Feature not implemented.