pub struct ProxyConfig {
pub trusted_proxies: Vec<String>,
pub trust_x_forwarded_for: bool,
pub trust_x_real_ip: bool,
}Fields
trusted_proxies: Vec<String>Trusted proxy CIDRs or IPs allowed to provide forwarded client IP headers.
trust_x_forwarded_for: boolTrust X-Forwarded-For when the direct peer is a trusted proxy.
trust_x_real_ip: boolTrust X-Real-IP when the direct peer is a trusted proxy.