pub struct Namespace(/* private fields */);Expand description
Dot-separated namespace.
Implementations
Sourceimpl Namespace
impl Namespace
Sourcepub fn check(&self) -> bool
pub fn check(&self) -> bool
Returns true when all namespace tokens are non-empty, trimmed and short enough.
Sourcepub fn at_level(&self, level: usize) -> Namespace
pub fn at_level(&self, level: usize) -> Namespace
Returns the namespace truncated to level segments.
Sourcepub fn is_ancestor_of(&self, other: &Namespace) -> bool
pub fn is_ancestor_of(&self, other: &Namespace) -> bool
Returns true when self is a strict ancestor of other.
Sourcepub fn is_ancestor_or_equal_of(&self, other: &Namespace) -> bool
pub fn is_ancestor_or_equal_of(&self, other: &Namespace) -> bool
Returns true when self is an ancestor of other or both are equal.
Sourcepub fn is_descendant_of(&self, other: &Namespace) -> bool
pub fn is_descendant_of(&self, other: &Namespace) -> bool
Returns true when self is a strict descendant of other.
Sourcepub fn is_parent_of(&self, other: &Namespace) -> bool
pub fn is_parent_of(&self, other: &Namespace) -> bool
Returns true when self is the direct parent of other.
Sourcepub fn is_child_of(&self, other: &Namespace) -> bool
pub fn is_child_of(&self, other: &Namespace) -> bool
Returns true when self is the direct child of other.
Sourcepub const fn is_top_level(&self) -> bool
pub const fn is_top_level(&self) -> bool
Returns true when the namespace has a single segment.