pub struct NetworkConfig {
pub node_type: NodeType,
pub listen_addresses: Vec<String>,
pub external_addresses: Vec<String>,
pub boot_nodes: Vec<RoutingNode>,
pub routing: Config,
pub control_list: Config,
pub memory_limits: MemoryLimitsConfig,
pub max_app_message_bytes: usize,
pub max_pending_outbound_bytes_per_peer: usize,
pub max_pending_inbound_bytes_per_peer: usize,
pub max_pending_outbound_bytes_total: usize,
pub max_pending_inbound_bytes_total: usize,
}Expand description
Network config
Fields
node_type: NodeTypeThe node type.
listen_addresses: Vec<String>Listen addresses.
external_addresses: Vec<String>External addresses.
boot_nodes: Vec<RoutingNode>Bootnodes to connect to.
routing: ConfigRouting configuration.
control_list: ConfigControl List configuration.
memory_limits: MemoryLimitsConfigMemory-based connection limit policy.
max_app_message_bytes: usizeMaximum accepted application message payload in bytes.
max_pending_outbound_bytes_per_peer: usizeMaximum buffered outbound bytes per peer while disconnected.
0 disables the per-peer bytes limit.
max_pending_inbound_bytes_per_peer: usizeMaximum buffered inbound bytes per peer before helper delivery.
0 disables the per-peer bytes limit.
max_pending_outbound_bytes_total: usizeMaximum total buffered outbound bytes across all peers while disconnected.
0 disables the global bytes limit.
max_pending_inbound_bytes_total: usizeMaximum total buffered inbound bytes across all peers before helper delivery.
0 disables the global bytes limit.
Implementations